function [Y,tau,phi]=Ground_Motion_Model(MW,R,SC,TOF,MA)
% First written by IEM  on 2023.11.28
% Copyright @ IEM, CEA; 
% Contact Email: renyefei@iem.net.cn (Ph. D. Yefei Ren) & liuye@iem.ac.cn (Ph.D. Ye Liu) 
%======================================================
%   Input:
%           MW----Moment Magnitude
%           R-----Hypdis(km)
%           SC----Site class(CN)：'I','II','III','IV'
%           TOF---Type of fault：'TF','TS','SS','NS','NF','U'
%           MA----MorA: 'M','A'
%   Output:
%           Y-----Ground Motion predicted value
%           tau---Between-event residual standard deviation
%           phi---Within-event residual standard deviation
%   Notice:
%        1. TF is Thrust fault; TS is Thrust slip fault
%           NF is Normal falut; NS is Normal slip fault
%           SS is strike slip fault; U is unknown 
%        2. Y contain PGA PGV and Sa for different period
%           Y(1:21) is Sa for period 0.01 0.02 0.03 0.05 ...
%           0.075 0.1 0.15 0.2 0.25 0.3 0.4 0.5 0.75 1.0  ...
%           1.5 2.0 3.0 4.0 5.0 7.5 10.0
%           Y(22) is PGA;Y(23) is PGV;
%        3. The unit of PGA and Sa is g;The unit of PGV is cm/s
%========================================================
%Read coefficience
coe_file='coefficience.xlsx';
coe=readmatrix(coe_file,'Sheet','Sheet1','Range','C2:W24');
c=coe(:,1:8); s=coe(:,9:11); f=coe(:,12:17); m=coe(:,18:19);
tau=coe(:,20); phi=coe(:,21);

%calculate IM
if (R>200)|| (R<=0)
    error("R range error")
end

%calculate f_mag
if (MW>=4)&& (MW<5.5)
    f_mag=c(:,1)+c(:,2).*MW;
elseif (MW>=5.5)&&(MW<6.5)
    f_mag=c(:,1)+c(:,2).*MW+c(:,3).*(MW-5.5);
elseif MW>=6.5&&(MW<=7.8)
    f_mag=c(:,1)+c(:,2).*MW+c(:,3).*(MW-5.5)+c(:,4).*(MW-6.5);
else
    error('Mw range error');
end

%calculate f_dis
f_dis=(c(:,5)+c(:,6).*MW).*log(sqrt(R^2+c(:,7).^2));

if R<80
    f_atn=0;
else
    f_atn=c(:,8)*(R-80);
end

%calculate f_site
switch SC
    case 'I'
    f_site=s(:,1);
    case 'II'
    f_site=s(:,2);
    case 'III'
    f_site=s(:,3);
    case 'IV'
    error('Currently IV site not supported');
    otherwise
    error('SiteClass error');
end

%calculate f_tof
switch TOF
    case 'TF'
        f_tof=f(:,1);
    case 'TS'
        f_tof=f(:,2);
    case 'SS'
        f_tof=f(:,3);
    case 'NS'
        f_tof=f(:,4);
    case 'NF'
        f_tof=f(:,5);
    case 'U'
        f_tof=0;
        warning('Type of fault Unknow');
    otherwise
        error('Type of fault error');
end

%calculate f_aft
switch MA
    case 'M'
        f_aft=m(:,1);
    case 'A'
        f_aft=m(:,2);
    otherwise
        error('MorA error');
end
        
ln_y=f_mag+f_dis+f_atn+f_site+f_tof+f_aft;
Y=exp(ln_y);


end